@@ -149,7 +149,7 @@ sub SetAttribute {
       IUP::Internal::LibraryIup::_IupSetAttributeHandle($self->ihandle, $k, $v->ihandle);      
       #assuming any element ref stored into iup attribute to be a child      
       unless($self->_get_child_ref($v)) {
-        #xxxFIXME - happens for: MENU, MDIMENU, IMAGE*, PARENTDIALOG (can cause memory leaks)
+        #XXX-FIXME - child element destruction: happens for: MENU, MDIMENU, IMAGE*, PARENTDIALOG (can cause memory leaks)
 	#during Destroy() we might destroy elements shared by more dialogs
         #warn "***DEBUG*** Unexpected situation elem='".ref($self)."' attr='$k'"; 
         $self->_store_child_ref($v); #xxx(ANTI)DESTROY-MAGIC
@@ -181,11 +181,23 @@ sub GetAttribute {
   #char *IupGetAttribute(Ihandle *ih, const char *name); [in C]
   #iup.GetAttribute(ih: ihandle, name: string) -> value: string [in Lua]
   my ($self, @names) = @_;
-  my @rv = ();  
+  my @rv = ();
   push(@rv, IUP::Internal::LibraryIup::_IupGetAttribute($self->ihandle, $_)) for (@names);    
   return (scalar(@names) == 1) ? $rv[0] : @rv; #xxxCHECKLATER not sure if this is a good idea
 }
 
+sub GetAttributeAsElement {
+  #special perl method
+  #XXX-FIXME needs testin g
+  my ($self, @names) = @_;
+  my @rv = ();
+  for (@names) {
+    my $v = IUP::Internal::LibraryIup::_IupGetAttribute($self->ihandle, $_);
+    push(@rv, defined $v ? IUP->GetByName($v) : undef);    
+  }
+  return (scalar(@names) == 1) ? $rv[0] : @rv; #xxxCHECKLATER not sure if this is a good idea
+}
+
 sub GetAttributeId {
   #char *IupGetAttributeId(Ihandle *ih, const char *name, int id); [in C]
   #iup.GetAttributeId(ih: ihandle, name: string, id: number) -> value: string [in Lua]
@@ -436,7 +448,7 @@ sub ShowXY {
   my ($self, $x, $y) = @_;
   $x = IUP_CURRENT unless defined $x;
   $y = IUP_CURRENT unless defined $y;
-  return IUP::Internal::LibraryIup::_IupShowXY($self->ihandle, $x, $y);  
+  return IUP::Internal::LibraryIup::_IupShowXY($self->ihandle, $x, $y);
 }
 
 sub GetNextChild {
@@ -550,7 +562,7 @@ sub NextField {
 
 sub DESTROY {
   #IMPORTANT: do not automatically destroy iup elements
-  #warn "***DEBUG*** DESTROY(): " . ref($_[0]) . " [" . $_[0]->ihandle . "]\n";  
+  #warn "XXX-DEBUG: IUP::Internal::Element::DESTROY(): " . ref($_[0]) . " [" . $_[0]->ihandle . "]\n";  
 }
 
 ###### INTERNAL HELPER FUNCTIONS
